pub enum InterfaceType {
Stub,
Proxy,
}Expand description
The type of a SOME/IP service interface.
This defines how it should process SOME/IP messages.
Variants
Stub
A service interface being served on a local endpoint.
Proxy
A service interface being served on a remote endpoint.