pub enum MethodType {
Procedure,
Method,
Event,
}Expand description
The type of a SOME/IP method.
This defines how it should process SOME/IP messages.
Variants
Procedure
A callable function on a service interface that does not return a value.
Method
A callable function on a service interface that returns a value.
Event
A non-callable event on the service interface.