MessageTypeField

Struct MessageTypeField 

pub struct MessageTypeField(/* private fields */);
MessageType and associated flags packed into a single byte.

Implementations

Source

impl MessageTypeField

pub const fn new(value: u8) -> Self

Creates a new MessageTypeField with the given value.

Examples
use rsomeip_proto::MessageTypeField;

let value = MessageTypeField::new(1 as u8);
assert_eq!(value.as_u8(), 1 as u8);
pub const fn as_u8(self) -> u8

Returns the u8 representation of this MessageTypeField.

Examples
use rsomeip_proto::MessageTypeField;

let value = MessageTypeField::new(1 as u8);
assert_eq!(value.as_u8(), 1 as u8);
Source

impl MessageTypeField

pub const TP_FLAG: u8 = 0x20

Transport Protocol flag. Determines if the message is a segment of a larger message.

pub const ALL_FLAGS: u8 = Self::TP_FLAG

A mask of all MessageTypeField flags.

pub const fn is_tp(&self) -> bool

Whether the Transport Protocol flag is set.

Examples
use rsomeip_proto::MessageTypeField;

assert!(!MessageTypeField::new(0).is_tp());
assert!(MessageTypeField::new(MessageTypeField::TP_FLAG).is_tp());
pub const fn flags(self) -> u8

Returns the mask of all currently enabled flags.

Examples
use rsomeip_proto::MessageTypeField;

let mask = MessageTypeField::new(MessageTypeField::TP_FLAG).flags();
assert_eq!(mask, MessageTypeField::TP_FLAG);
pub const fn with_flags(self, flags: u8, enabled: bool) -> Self

Returns this MessageTypeField with the given flags set to enabled.

Examples
use rsomeip_proto::MessageTypeField;

let field = MessageTypeField::default()
    .with_flags(MessageTypeField::TP_FLAG, true);
assert_eq!(field.flags(), MessageTypeField::TP_FLAG);

let field = field.with_flags(MessageTypeField::TP_FLAG, false);
assert_eq!(field.flags(), 0);
pub const fn as_type(self) -> MessageType

Returns the MessageType representation of this MessageTypeField.

Ignores all flags.

Examples
use rsomeip_proto::{MessageType, MessageTypeField};

let field = MessageTypeField::new(0x80);
assert_eq!(field.as_type(), MessageType::Response);
pub const fn from_type(value: MessageType) -> Self

Creates a new MessageTypeField from the given MessageType.

Examples
use rsomeip_proto::{MessageType, MessageTypeField};

let field = MessageTypeField::from_type(MessageType::Response);
assert_eq!(field.as_u8(), 0x80);