#[non_exhaustive]pub enum MessageType {
Request,
RequestNoReturn,
Notification,
Response,
Error,
Unknown(u8),
}Expand description
Type of a SOME/IP message.
It’s used both by servers and clients to specify how the message should be interpreted by the peer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Request
A request expecting a response.
RequestNoReturn
A fire-and-forget request.
Notification
A notification or event callback expecting no response.
Response
A response message.
Error
A response containing an error.
Unknown(u8)
Unknown message type.
Implementations