pub struct MessageTypeField(/* private fields */);Expand description
MessageType and associated flags packed into a single byte.
Implementations
Sourceimpl MessageTypeField
impl MessageTypeField
Sourcepub const fn new(value: u8) -> Self
pub const fn new(value: u8) -> Self
Creates a new MessageTypeField with the given value.
Examples
use rsomeip_proto::MessageTypeField;
let value = MessageTypeField::new(1 as u8);
assert_eq!(value.as_u8(), 1 as u8);Sourceimpl MessageTypeField
impl MessageTypeField
Sourcepub const TP_FLAG: u8 = 0x20
pub const TP_FLAG: u8 = 0x20
Transport Protocol flag. Determines if the message is a segment of a larger message.
Sourcepub const ALL_FLAGS: u8 = Self::TP_FLAG
pub const ALL_FLAGS: u8 = Self::TP_FLAG
A mask of all MessageTypeField flags.
Sourcepub const fn is_tp(&self) -> bool
pub const fn is_tp(&self) -> bool
Whether the Transport Protocol flag is set.
Examples
use rsomeip_proto::MessageTypeField;
assert!(!MessageTypeField::new(0).is_tp());
assert!(MessageTypeField::new(MessageTypeField::TP_FLAG).is_tp());Sourcepub const fn flags(self) -> u8
pub const fn flags(self) -> u8
Returns the mask of all currently enabled flags.
Examples
use rsomeip_proto::MessageTypeField;
let mask = MessageTypeField::new(MessageTypeField::TP_FLAG).flags();
assert_eq!(mask, MessageTypeField::TP_FLAG);Sourcepub const fn with_flags(self, flags: u8, enabled: bool) -> Self
pub const fn with_flags(self, flags: u8, enabled: bool) -> Self
Returns this MessageTypeField with the given flags set to enabled.
Examples
use rsomeip_proto::MessageTypeField;
let field = MessageTypeField::default()
.with_flags(MessageTypeField::TP_FLAG, true);
assert_eq!(field.flags(), MessageTypeField::TP_FLAG);
let field = field.with_flags(MessageTypeField::TP_FLAG, false);
assert_eq!(field.flags(), 0);Sourcepub const fn as_type(self) -> MessageType
pub const fn as_type(self) -> MessageType
Returns the MessageType representation of this MessageTypeField.
Ignores all flags.
Examples
use rsomeip_proto::{MessageType, MessageTypeField};
let field = MessageTypeField::new(0x80);
assert_eq!(field.as_type(), MessageType::Response);Sourcepub const fn from_type(value: MessageType) -> Self
pub const fn from_type(value: MessageType) -> Self
Creates a new MessageTypeField from the given MessageType.
Examples
use rsomeip_proto::{MessageType, MessageTypeField};
let field = MessageTypeField::from_type(MessageType::Response);
assert_eq!(field.as_u8(), 0x80);Trait Implementations
Sourceimpl Clone for MessageTypeField
impl Clone for MessageTypeField
Sourcefn clone(&self) -> MessageTypeField
fn clone(&self) -> MessageTypeField
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageTypeField
impl Debug for MessageTypeField
Sourceimpl Default for MessageTypeField
impl Default for MessageTypeField
Sourcefn default() -> MessageTypeField
fn default() -> MessageTypeField
Returns the “default value” for a type. Read more
Sourceimpl Deserialize for MessageTypeField
impl Deserialize for MessageTypeField
Sourcetype Output = MessageTypeField
type Output = MessageTypeField
Type of the data that will be deserialized.
Sourcefn deserialize(buffer: &mut impl Buf) -> Result<Self::Output, DeserializeError>
fn deserialize(buffer: &mut impl Buf) -> Result<Self::Output, DeserializeError>
Deserializes an instance of
Deserialize::Output from the buffer. Read moreSourcefn deserialize_len(
length: LengthField,
buffer: &mut impl Buf,
) -> Result<Self::Output, DeserializeError>
fn deserialize_len( length: LengthField, buffer: &mut impl Buf, ) -> Result<Self::Output, DeserializeError>
Deserializes an instance of
Deserialize::Output from the buffer. Read moreSourceimpl Display for MessageTypeField
impl Display for MessageTypeField
Sourceimpl From<MessageTypeField> for u8
impl From<MessageTypeField> for u8
Sourcefn from(value: MessageTypeField) -> Self
fn from(value: MessageTypeField) -> Self
Converts to this type from the input type.
Sourceimpl From<u8> for MessageTypeField
impl From<u8> for MessageTypeField
Sourceimpl PartialEq for MessageTypeField
impl PartialEq for MessageTypeField
Sourceimpl Serialize for MessageTypeField
impl Serialize for MessageTypeField
Sourcefn serialize(&self, buffer: &mut impl BufMut) -> Result<usize, SerializeError>
fn serialize(&self, buffer: &mut impl BufMut) -> Result<usize, SerializeError>
Serializes the implementing type into the buffer. Read more
Sourcefn serialize_len(
&self,
length: LengthField,
buffer: &mut impl BufMut,
) -> Result<usize, SerializeError>
fn serialize_len( &self, length: LengthField, buffer: &mut impl BufMut, ) -> Result<usize, SerializeError>
Serializes the implementing type into the buffer. Read more
impl Copy for MessageTypeField
impl Eq for MessageTypeField
impl StructuralPartialEq for MessageTypeField